summaryrefslogtreecommitdiff
path: root/src/casefiddle.c
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2013-12-19 19:51:18 +0200
committerEli Zaretskii <eliz@gnu.org>2013-12-19 19:51:18 +0200
commit79f7284f9607a4a9edf53f8643825e699d3683f6 (patch)
tree6cd7e2e5f1a767b3af3c70ede4e9338cb93e44bd /src/casefiddle.c
parent8f2be364dc35feb39ea2274bd9d52cf2980227c7 (diff)
downloademacs-79f7284f9607a4a9edf53f8643825e699d3683f6.tar.gz
Fix bug #16190 with documentation of capitalize-word.
src/casefiddle.c (Fupcase_word, Fdowncase_word, Fcapitalize_word): Doc fix.
Diffstat (limited to 'src/casefiddle.c')
-rw-r--r--src/casefiddle.c19
1 files changed, 16 insertions, 3 deletions
diff --git a/src/casefiddle.c b/src/casefiddle.c
index 9b213bb3cf2..a75dc448c36 100644
--- a/src/casefiddle.c
+++ b/src/casefiddle.c
@@ -365,7 +365,11 @@ operate_on_word (Lisp_Object arg, ptrdiff_t *newpoint)
}
DEFUN ("upcase-word", Fupcase_word, Supcase_word, 1, 1, "p",
- doc: /* Convert following word (or ARG words) to upper case, moving over.
+ doc: /* Convert to upper case from point to end of word, moving over.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
With negative argument, convert previous words but do not move.
See also `capitalize-word'. */)
(Lisp_Object arg)
@@ -380,7 +384,11 @@ See also `capitalize-word'. */)
}
DEFUN ("downcase-word", Fdowncase_word, Sdowncase_word, 1, 1, "p",
- doc: /* Convert following word (or ARG words) to lower case, moving over.
+ doc: /* Convert to lower case from point to end of word, moving over.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
With negative argument, convert previous words but do not move. */)
(Lisp_Object arg)
{
@@ -394,9 +402,14 @@ With negative argument, convert previous words but do not move. */)
}
DEFUN ("capitalize-word", Fcapitalize_word, Scapitalize_word, 1, 1, "p",
- doc: /* Capitalize the following word (or ARG words), moving over.
+ doc: /* Capitalize from point to the end of word, moving over.
+With numerical argument ARG, capitalize the next ARG-1 words as well.
This gives the word(s) a first character in upper case
and the rest lower case.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
With negative argument, capitalize previous words but do not move. */)
(Lisp_Object arg)
{